# Appendices to Translation Notes

## Decisions Concerning Translation Notes

The Translation Notes are written for words and phrases in the Unlocked Literal Bible. Some of the notes explain the meaning of a word or phrase, and some of the notes suggest ways of translating them. When Bible scholars are not sure of the meaning of a word or phrase, the notes tell about the most probable meaning first, and then the other reasonable meanings afterward.

Generally notes are not written about words that are explained in Translation Words. However, if a word has more than one use, there may be a note that tells how the word is used in that verse.

## How to use Translation Notes

The notes are intended to help translators understand Bible passages well so that they can translate them accurately. Translators are not expected to use all of the translation suggestions that are given in the notes. They are only there so that if translators have difficulty with a particular phrase, the suggestion can give them ideas of how they might translate it.

Some of the notes have links to topics in the Translation Manual. These  topics are meant to  help translators understand the translation issues addressed in the notes and to see different strategies for dealing with those issues.

## Types of Translation Notes

### Connecting Statement and General Information

Sometimes, at the top of the list of notes, there are notes that start with **Connecting Statement** or **General Information**. A **connecting statement** tells how the verse is related to earlier verses.  A **general information** note tells about issues in the verse that cover more than one phrase. Both types of notes are to help you understand the passage better and be aware of issues that you might need to address in translation.

### Notes with Definitions

Sometimes you may not know what a word in the ULB means. The notes may have a definition or a description of the word or phrase to help you understand what it means.

### Notes that Explain
Sometimes you may not know what a word or phrase means in the ULB, and it may also be used in the UDB. In this case, it will be explained in the notes. These explanations are meant to help you understand the word or phrase. Do not translate the explanations into your Bible. Use them to help you understand the meaning so you can translate the Bible text correctly.

### Notes with Synonyms and Equivalent Phrases
Some Notes provide a translation suggestion that can replace the word or phrase that they quote from the ULB. These replacements can fit into the sentence without changing the meaning of the sentence. These are synonyms and equivalent phrases and are written in double-quotes. These mean the same as the text in the ULB. This kind of Note can help you to think of other ways to say the same thing, in case the word or phrase in the ULB does not seem to have a natural equivalent in your language.

### Notes about Alternate Translations
Sometimes if people try to translate a sentence using the same form as the ULB, it may result in a wrong meaning, or it may be unclear or unnatural in their language. So some Translation Notes have the words “Alternate translation” followed by one or more translations. These translations express the same meaning as the ULB, but with a different form. If following the form of the ULB would not give the correct meaning in a clear and natural way, translators may use the alternate translations to help them think of ways of expressing the idea clearly in their own language.

The alternate translation suggestion may involve, for example, stating implicit information clearly, changing passive voice to active, or rewording rhetorical questions as statements. The notes often explain why there is an alternate translation and have a link to a page that explains the topic.

### Notes about Alternate Meanings

Sometimes Bible scholars do not know for sure, or do not agree on, what a particular phrase or sentence in the Bible means. When many scholars say that a word or phrase means one thing, and many others say that it means other things, we often have notes showing the most common meanings that they give.

Sometimes translators can translate the text into their language in such a way that readers can understand any of the possible meanings. Sometimes translators have to decide which meaning to translate. When the ULB translators had to choose one of the meanings in order to make the text understandable, the notes tell about the meanings that are used in other versions.

The translator needs to decide which meaning to translate. He may choose the meaning used in the ULB or he may choose one of the other meanings if the people in their community use and respect another Bible version that has one of those other meanings.


### Notes about Probable or Possible Meanings
Sometimes Bible scholars do not know for sure, or do not agree on, what a particular phrase or sentence in the Bible means. When the ULB translators could translate the text in a way such that readers can understand the multiple meanings, our notes begin with "Possible meanings are" and then give a numbered list. We recommend that you use the first meaning given. However, if people in your community have access to another Bible that uses one of the other possible meanings, you may decide that it is better to use that meaning.

### Notes with Links

There are two types of links in the Translation Notes: links to a translation topic and links another verse in the same book.

**Links to Translation Topics**  
Translation notes address various language and translation issues. Sometimes at the end of a translation note there is a statement in parentheses that may look like this: (See: Metaphor). The word or phrase after "See:" is a link to a translation topic in the Translation Manual. The topic deals with an issue that the note addresses. You can click on the link to learn more about the topic.

There are several reasons to read the topic information:

* Learning about the topic will help the translator to translate more accurately.
* The topics have been chosen to provide a basic understanding of the principles and strategies of translation.


**Links to Another Verse in the Same Book**  
In some Translation Notes there is a sentence that may look like this: See how you translated this in Genesis 1:5. This is because sometimes a word or phrase is used in the same way multiple times in one book.

There are several reasons why you will want to see how you had translated the word or phrase before:

* This will make it easier for you to translate this phrase by reminding you of how you have already translated it.
* This will make your translation faster and more consistent because you will be reminded to translate that phrase in the same way each time.

### Notes That Identify Figures of Speech
Figures of speech are ways of saying things that use words in non-literal ways. That is, the meaning of a figure of speech is not the same as the more direct meaning of its words. There are many different types of figures of speech.

In the Translation Notes there will be an explanation about the meaning of a figure of speech that is in the passage. Sometimes an alternate translation is provided. There will also be a link to page in the translation topics section of the Translation Manual that gives additional information and strategies for that kind of figure of speech.

In order to translate the meaning, you need to be able to recognize the figure of speech and know what it means in the source language. Then you can choose either a figure of speech or a direct way to communicate that same meaning in the target language.

### Notes that Identify Indirect and Direct Quotes
There are two kinds of quotations: direct quotation and indirect quotation. When translating a quotation, translators need to decide whether to translate it as a direct quotation or an indirect quotation.

When there is a quote in the ULB, the note may have an option for translating it as the other kind of quote. The translation suggestion may start with "It can be translated as a direct quote:" or "It can be translated as an indirect quote:" and it will be followed by that kind of quote. This will be followed by a link to the translation topic page that explains both kinds of quotations: "[Direct and Indirect Quotations](../figs-quotations/01.md)" 

There may be a note about direct and indirect quotes when a quote has another quote inside of it, because these can be confusing. In some languages it may be more natural to translate one of these quotes with a direct quote and the other quote with an indirect quote. The note will also have a link to the translation topic page called "[Quotes within Quotes](../figs-quotesinquotes/01.md)."

### Notes for Long ULB Phrases
Sometimes there are notes for a phrase and separate notes for portions of that phrase. In that case, the larger phrase is usually explained first, and its parts afterward.

## Contributors to Translation Notes

{{manifest}}